@@ -1,5 +1,6 @@
-mod controls;
-mod flows;
+mod prime;
+
+mod utils;
 
 use pyo3::exceptions::PyTypeError;
 use pyo3::prelude::*;
@@ -25,14 +26,10 @@ fn uninstall(_py: Python) -> PyResult<()> {
 /// Don't forget to add these classes
 /// to `__init__.py`!
 #[pymodule]
-fn rillrate(_py: Python<'_>, m: &PyModule) -> PyResult<()> {
+fn rillrate(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add("__version__", env!("CARGO_PKG_VERSION"))?;
     m.add_wrapped(wrap_pyfunction!(install))?;
     m.add_wrapped(wrap_pyfunction!(uninstall))?;
-
-    controls::init(_py, m)?;
-    flows::init(_py, m)?;
-
-    //m.add_class::<Logger>()?;
+    prime::register(py, m)?;
     Ok(())
 }
